@@ -7,7 +7,8 @@ BEGIN { use_ok( 'WWW::Gazetteer' ); }
 my $g = WWW::Gazetteer->new();
 is_deeply($g->fetch("London", "United Kingdom"),
   { longitude => "-0.1167", latitude => "51.5000" });
-is_deeply($g->fetch("Nice", "France"),
+my $nice = $g->fetch("Nice", "France");
+is_deeply($nice,
   { longitude => "7.2500", latitude => "43.7000"});
 is_deeply([$g->fetch("Bacton", "United Kingdom")], [
   { longitude => "-2.9167", latitude => "51.9833" },
